#define F_CPU   4e6     // 4MHz
#include <stdint.h>

/********************************************** Touch *******************/
#define TOUCHMUX0       4
#define TOUCHMUX1       5
#define TOUCH_PORT0     SBIT(PORTC, TOUCHMUX0)
#define TOUCH_DDR0      SBIT(DDRC, TOUCHMUX0)
#define TOUCH_PORT1     SBIT(PORTC, TOUCHMUX1)
#define TOUCH_DDR1      SBIT(DDRC, TOUCHMUX1)
#define THRESHOLD       10

#define KEY_LEFT        (1<<0)                  // touch keys
#define KEY_RIGHT       (1<<1)

#define ADC_PRESCALER(fmax) (F_CPU / fmax < 2  ? 1 : \
                             F_CPU / fmax < 4  ? 2 : \
                             F_CPU / fmax < 8  ? 3 : \
                             F_CPU / fmax < 16 ? 4 : \
                             F_CPU / fmax < 32 ? 5 : \
                             F_CPU / fmax < 64 ? 6 : 7)
#define ADC_SAMPLE_FREQ(pre) (F_CPU / 13.0 / ((pre & 0x07) ? 1<<(pre & 0x07) : 2))

#define ADCSRA_START (1<<ADEN | 1<<ADSC | 1<<ADIE | ADC_PRESCALER(100e3))       // 50..200kHz
#define ADMUX_GND (1<<REFS0 | 1<<MUX3 | 1<<MUX2 | 1<<MUX1 | 1<<MUX0)

#define touch_enable()     ADCSRA = ADCSRA_START

typedef struct
{
  uint16_t val;
  uint16_t comp;
}touch_t;

extern touch_t touch[2];

void touch_init(void);
uint8_t get_key_press(uint8_t key_mask);
uint8_t get_key_rpt(uint8_t key_mask);
uint8_t get_key_short(uint8_t key_mask);
uint8_t get_key_long(uint8_t key_mask);
